@@ -1,7 +1,7 @@
 import warnings
 
 from doctest import DocTestSuite
-from itertools import combinations, permutations
+from itertools import combinations, count, permutations
 from math import factorial
 from unittest import TestCase
 
@@ -166,13 +166,14 @@ class QuantifyTests(TestCase):
 
 
 class PadnoneTests(TestCase):
-    """Tests for ``padnone()``"""
-
-    def test_happy_path(self):
-        """wrapper iterator should return None indefinitely"""
-        r = range(2)
-        p = mi.padnone(r)
-        self.assertEqual([0, 1, None, None], [next(p) for _ in range(4)])
+    def test_basic(self):
+        iterable = range(2)
+        for func in (mi.pad_none, mi.padnone):
+            with self.subTest(func=func):
+                p = func(iterable)
+                self.assertEqual(
+                    [0, 1, None, None], [next(p) for _ in range(4)]
+                )
 
 
 class NcyclesTests(TestCase):
@@ -654,3 +655,33 @@ class PrependTests(TestCase):
         actual = tuple(mi.prepend(value, iterator))
         expected = ('ab',) + tuple('cdefg')
         self.assertEqual(actual, expected)
+
+
+class Convolvetests(TestCase):
+    def test_moving_average(self):
+        signal = iter([10, 20, 30, 40, 50])
+        kernel = [0.5, 0.5]
+        actual = list(mi.convolve(signal, kernel))
+        expected = [
+            (10 + 0) / 2,
+            (20 + 10) / 2,
+            (30 + 20) / 2,
+            (40 + 30) / 2,
+            (50 + 40) / 2,
+            (0 + 50) / 2,
+        ]
+        self.assertEqual(actual, expected)
+
+    def test_derivative(self):
+        signal = iter([10, 20, 30, 40, 50])
+        kernel = [1, -1]
+        actual = list(mi.convolve(signal, kernel))
+        expected = [10 - 0, 20 - 10, 30 - 20, 40 - 30, 50 - 40, 0 - 50]
+        self.assertEqual(actual, expected)
+
+    def test_infinite_signal(self):
+        signal = count()
+        kernel = [1, -1]
+        actual = mi.take(5, mi.convolve(signal, kernel))
+        expected = [0, 1, 1, 1, 1]
+        self.assertEqual(actual, expected)
